@@ -43,7 +43,7 @@ If you have downloaded a ``.bsp`` file, you can run ``jplephem`` from
 the command line to display the data inside of it::
 
     python -m jplephem comment de421.bsp
-    python -m jplephem dap de421.bsp
+    python -m jplephem daf de421.bsp
     python -m jplephem spk de421.bsp
 
 You can also take a large ephemeris and produce a smaller excerpt by
@@ -51,6 +51,13 @@ limiting the range of dates that it covers::
 
     python -m jplephem excerpt 2018/1/1 2018/4/1 de421.bsp excerpt421.bsp
 
+You can also filter by the integer codes for the targets you need.
+Unrecognized targets will not raise an error, to let you apply a master
+list of targets to a whole series of SPK files that might or might not
+each have all of the targets::
+
+    python -m jplephem excerpt --targets 1,2,3 2018/1/1 2018/4/1 de421.bsp excerpt421.bsp
+
 If the input ephemeris is a URL, then `jplephem` will try to save
 bandwidth by fetching only the blocks of the remote file that are
 necessary to cover the dates you have specified.  For example, the
@@ -82,21 +89,21 @@ SPK file and learn about the segments it offers:
 >>> kernel = SPK.open('de421.bsp')
 >>> print(kernel)
 File type DAF/SPK and format LTL-IEEE with 15 segments:
-2414864.50..2471184.50  Solar System Barycenter (0) -> Mercury Barycenter (1)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Venus Barycenter (2)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Earth Barycenter (3)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Mars Barycenter (4)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Jupiter Barycenter (5)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Saturn Barycenter (6)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Uranus Barycenter (7)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Neptune Barycenter (8)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Pluto Barycenter (9)
-2414864.50..2471184.50  Solar System Barycenter (0) -> Sun (10)
-2414864.50..2471184.50  Earth Barycenter (3) -> Moon (301)
-2414864.50..2471184.50  Earth Barycenter (3) -> Earth (399)
-2414864.50..2471184.50  Mercury Barycenter (1) -> Mercury (199)
-2414864.50..2471184.50  Venus Barycenter (2) -> Venus (299)
-2414864.50..2471184.50  Mars Barycenter (4) -> Mars (499)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Mercury Barycenter (1)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Venus Barycenter (2)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Earth Barycenter (3)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Mars Barycenter (4)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Jupiter Barycenter (5)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Saturn Barycenter (6)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Uranus Barycenter (7)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Neptune Barycenter (8)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Pluto Barycenter (9)
+2414864.50..2471184.50  Type 2  Solar System Barycenter (0) -> Sun (10)
+2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Moon (301)
+2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Earth (399)
+2414864.50..2471184.50  Type 2  Mercury Barycenter (1) -> Mercury (199)
+2414864.50..2471184.50  Type 2  Venus Barycenter (2) -> Venus (299)
+2414864.50..2471184.50  Type 2  Mars Barycenter (4) -> Mars (499)
 
 Since the next few examples involve vector output, let’s tell NumPy to
 make vector output attractive.
@@ -187,8 +194,8 @@ provided above and read through the code to learn more.
 
   >>> segment = kernel[3,399]
   >>> print(segment.describe())
-  2414864.50..2471184.50  Earth Barycenter (3) -> Earth (399)
-    frame=1 data_type=2 source=DE-0421LE-0421
+  2414864.50..2471184.50  Type 2  Earth Barycenter (3) -> Earth (399)
+    frame=1 source=DE-0421LE-0421
 
 * Each ``Segment`` loaded from the kernel has a number of attributes
   that are loaded from the SPK file:
@@ -351,6 +358,11 @@ https://github.com/brandon-rhodes/python-jplephem/
 Changelog
 ---------
 
+**2020 September 2 — Version 2.15**
+
+* The ``excerpt`` subcommand now accepts a ``--targets`` option to save
+  space by copying only matching segments into the output SPK file.
+
 **2020 March 26 — Version 2.14**
 
 * Fall back to plain file I/O on platforms that support ``fileno()`` but
